@@ -1,12 +1,9 @@
 package Javonet::Core::Handler::CommandHandler::SetInstanceFieldHandler;
-use aliased 'Javonet::Core::Handler::PerlHandler' => 'PerlHandler';
 use strict;
 use warnings FATAL => 'all';
-use Moose;
 use lib 'lib';
-use lib 'data_seed';
+use Moose;
 use Nice::Try;
-use Data::Dumper;
 use aliased 'Javonet::Core::Exception::Exception' => 'Exception';
 extends 'Javonet::Core::Handler::CommandHandler::AbstractCommandHandler';
 
@@ -31,8 +28,7 @@ sub process {
         my $field_name = $command->{payload}[1];
         my $new_value = $command->{payload}[2];
 
-        no strict 'refs';
-        ${"${instance}->${field_name}"} = $new_value;
+        $instance->{$field_name} = $new_value;
         return 0;
     }
     catch ($e){
